@@ -1,4 +1,5 @@
 from .clients import GetClientsResponse
+from .consents import GetConsentsResponse
 from .credentials import GetClientCredentialsResponse
 from .identities import GetIdentitiesResponse, GetIdentityProvidersResponse
 from .oauth import OAuthDependentTokenResponse, OAuthTokenResponse
@@ -11,6 +12,7 @@ __all__ = (
     "GetClientsResponse",
     "GetIdentitiesResponse",
     "GetIdentityProvidersResponse",
+    "GetConsentsResponse",
     "GetPoliciesResponse",
     "GetProjectsResponse",
     "GetScopesResponse",
