@@ -3,10 +3,13 @@ from __future__ import annotations
 import typing as t
 import uuid
 
-from globus_sdk import client, paging, response, scopes, utils
+from globus_sdk import client, exc, paging, response, scopes, utils
 from globus_sdk._types import UUIDLike
 from globus_sdk.authorizers import GlobusAuthorizer
+from globus_sdk.experimental.globus_app import GlobusApp
+from globus_sdk.scopes import Scope
 
+from .connector_table import ConnectorTable
 from .data import (
     CollectionDocument,
     EndpointDocument,
@@ -44,6 +47,8 @@ class GCSClient(client.BaseClient):
         self,
         gcs_address: str,
         *,
+        app: GlobusApp | None = None,
+        app_scopes: list[Scope] | None = None,
         environment: str | None = None,
         authorizer: GlobusAuthorizer | None = None,
         app_name: str | None = None,
@@ -58,9 +63,13 @@ class GCSClient(client.BaseClient):
             # if it doesn't, add it
             gcs_address = utils.slash_join(gcs_address, "/api/")
 
+        self._endpoint_client_id: str | None = None
+
         super().__init__(
             base_url=gcs_address,
             environment=environment,
+            app=app,
+            app_scopes=app_scopes,
             authorizer=authorizer,
             app_name=app_name,
             transport_params=transport_params,
@@ -97,29 +106,104 @@ class GCSClient(client.BaseClient):
     @staticmethod
     def connector_id_to_name(connector_id: UUIDLike) -> str | None:
         """
-        Helper that converts a given connector_id into a human readable
-        connector name string. Will return None if the id is not recognized.
+        .. warning::
 
-        Note that it is possible for valid connector_ids to be unrecognized
-        due to differing SDK and GCS versions.
+            This method is deprecated -- use
+            ``ConnectorTable.lookup`` instead.
+
+        Helper that converts a given connector ID into a human-readable
+        connector name string.
 
         :param connector_id: The ID of the connector
         """
-        connector_dict = {
-            "7c100eae-40fe-11e9-95a3-9cb6d0d9fd63": "Box",
-            "1b6374b0-f6a4-4cf7-a26f-f262d9c6ca72": "Ceph",
-            "56366b96-ac98-11e9-abac-9cb6d0d9fd63": "Google Cloud Storage",
-            "976cf0cf-78c3-4aab-82d2-7c16adbcc281": "Google Drive",
-            "145812c8-decc-41f1-83cf-bb2a85a2a70b": "POSIX",
-            "7643e831-5f6c-4b47-a07f-8ee90f401d23": "S3",
-            "7e3f3f5e-350c-4717-891a-2f451c24b0d4": "SpectraLogic BlackPearl",
-        }
-        return connector_dict.get(str(connector_id))
+        exc.warn_deprecated(
+            "`connector_id_to_name` has been replaced with "
+            "`ConnectorTable.lookup`. Use that instead, "
+            "and retrieve the `name` attribute from the result."
+        )
+        connector_obj = ConnectorTable.lookup(connector_id)
+        if connector_obj is None:
+            return None
+        name = connector_obj.name
+        # compatibility shim due to name change in the data (which was updated to
+        # match internal sources referring to this only as "BlackPearl")
+        if name == "BlackPearl":
+            name = "Spectralogic BlackPearl"
+        return name
+
+    @property
+    def default_scope_requirements(self) -> list[Scope]:
+        return [
+            Scope(
+                GCSClient.get_gcs_endpoint_scopes(
+                    self.endpoint_client_id
+                ).manage_collections
+            )
+        ]
+
+    @utils.classproperty
+    def resource_server(  # pylint: disable=missing-param-doc
+        self_or_cls: client.BaseClient | type[client.BaseClient],
+    ) -> str | None:
+        """
+        The resource server for a GCS endpoint is the ID of its GCS Manager Client.
+
+        This will return None if called as a classmethod as an instantiated
+        ``GCSClient`` is required to look up the client ID from the endpoint.
+        """
+        if not isinstance(self_or_cls, GCSClient):
+            return None
+
+        return self_or_cls.endpoint_client_id
+
+    @property
+    def endpoint_client_id(self) -> str:
+        """
+        The UUID of the GCS Manager client of the endpoint this client is configured
+        for. This will be equal to the ``endpoint_id`` in most cases, but when they
+        differ the ``client_id`` is the canonical value for the endpoint's resource
+        server and scopes.
+        """
+        if self._endpoint_client_id:
+            return self._endpoint_client_id
+
+        else:
+            data = self.get_gcs_info()
+            try:
+                endpoint_id = str(data["client_id"])
+            except KeyError:
+                print(data)
+            self._endpoint_client_id = endpoint_id
+            return endpoint_id
 
     #
     # endpoint methods
     #
 
+    def get_gcs_info(
+        self, query_params: dict[str, t.Any] | None = None
+    ) -> UnpackingGCSResponse:
+        """
+        Get information about the GCS Manager service this client is configured for.
+        This call is made unauthenticated.
+
+        :param query_params: Additional passthrough query parameters
+
+        .. tab-set::
+
+            .. tab-item:: API Info
+
+                ``GET /info``
+
+                .. extdoclink:: Get Endpoint
+                    :ref: openapi/#getInfo
+                    :service: gcs
+        """
+        return UnpackingGCSResponse(
+            self.get("/info", query_params=query_params, automatic_authorization=False),
+            "info",
+        )
+
     def get_endpoint(
         self, query_params: dict[str, t.Any] | None = None
     ) -> UnpackingGCSResponse:
